[cig-commits] commit: Change the internal name from CellStokes* to Stokes*

Mercurial hg at geodynamics.org
Fri Feb 25 14:12:54 PST 2011


changeset:   14:3e8175cdd1ef
user:        Walter Landry <wlandry at caltech.edu>
date:        Fri Dec 31 12:23:51 2010 -0800
files:       FACStokes.h FACStokes/solveStokes.C StokesFACOps.C StokesFACOps.I StokesFACOps.h StokesFACSolver.C StokesFACSolver.I StokesFACSolver.h StokesHypreSolver.C StokesHypreSolver.I StokesHypreSolver.h
description:
Change the internal name from CellStokes* to Stokes*


diff -r fe2a9230921b -r 3e8175cdd1ef FACStokes/solveStokes.C
--- a/FACStokes/solveStokes.C	Fri Dec 31 12:10:26 2010 -0800
+++ b/FACStokes/solveStokes.C	Fri Dec 31 12:23:51 2010 -0800
@@ -58,7 +58,7 @@ namespace SAMRAI {
 
     /*
      * Set the parameters for the Stokes equation.
-     * See classes solv::CellStokesFACSolver or
+     * See classes solv::StokesFACSolver or
      * solv::StokesSpecifications.
      * (D is the diffusion coefficient.
      * C is the source term which is not used in this example.)
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACOps.C
--- a/StokesFACOps.C	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACOps.C	Fri Dec 31 12:23:51 2010 -0800
@@ -51,20 +51,20 @@ namespace solv {
 namespace solv {
 
 tbox::Pointer<pdat::CellVariable<double> >
-CellStokesFACOps::s_cell_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
+StokesFACOps::s_cell_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
 
 tbox::Pointer<pdat::SideVariable<double> >
-CellStokesFACOps::s_flux_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
+StokesFACOps::s_flux_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
 
 tbox::Pointer<pdat::OutersideVariable<double> >
-CellStokesFACOps::s_oflux_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
+StokesFACOps::s_oflux_scratch_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
 
 tbox::StartupShutdownManager::Handler
-CellStokesFACOps::s_finalize_handler(
+StokesFACOps::s_finalize_handler(
    0,
    0,
    0,
-   CellStokesFACOps::finalizeCallback,
+   StokesFACOps::finalizeCallback,
    tbox::StartupShutdownManager::priorityVariables);
 
 extern "C" {
@@ -555,7 +555,7 @@ void F77_FUNC(ewingfixfluxcondc3d, EWING
  * Constructor.                                                     *
  ********************************************************************
  */
-CellStokesFACOps::CellStokesFACOps(
+StokesFACOps::StokesFACOps(
    const tbox::Dimension& dim,
    const std::string& object_name,
    tbox::Pointer<tbox::Database> database):
@@ -621,22 +621,22 @@ CellStokesFACOps::CellStokesFACOps(
 {
 
    t_restrict_solution = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::restrictSolution()");
+      getTimer("solv::StokesFACOps::restrictSolution()");
    t_restrict_residual = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::restrictResidual()");
+      getTimer("solv::StokesFACOps::restrictResidual()");
    t_prolong = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::prolongErrorAndCorrect()");
+      getTimer("solv::StokesFACOps::prolongErrorAndCorrect()");
    t_smooth_error = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::smoothError()");
+      getTimer("solv::StokesFACOps::smoothError()");
    t_solve_coarsest = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::solveCoarsestLevel()");
+      getTimer("solv::StokesFACOps::solveCoarsestLevel()");
    t_compute_composite_residual = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::computeCompositeResidualOnLevel()");
+      getTimer("solv::StokesFACOps::computeCompositeResidualOnLevel()");
    t_compute_residual_norm = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesFACOps::computeResidualNorm()");
+      getTimer("solv::StokesFACOps::computeResidualNorm()");
 
    if (d_dim == tbox::Dimension(1) || d_dim > tbox::Dimension(3)) {
-      TBOX_ERROR("CellStokesFACOps : DIM == 1 or > 3 not implemented yet.\n");
+      TBOX_ERROR("StokesFACOps : DIM == 1 or > 3 not implemented yet.\n");
    }
 
    if (s_cell_scratch_var[dim.getValue() - 1].isNull()) {
@@ -644,15 +644,15 @@ CellStokesFACOps::CellStokesFACOps(
       TBOX_ASSERT(s_cell_scratch_var[dim.getValue() - 1].isNull());
 
       std::ostringstream ss;
-      ss << "CellStokesFACOps::private_cell_scratch" << dim.getValue();
+      ss << "StokesFACOps::private_cell_scratch" << dim.getValue();
       s_cell_scratch_var[dim.getValue() - 1] = new pdat::CellVariable<double>
             (dim, ss.str());
       ss.str("");
-      ss << "CellStokesFACOps::private_flux_scratch" << dim.getValue();
+      ss << "StokesFACOps::private_flux_scratch" << dim.getValue();
       s_flux_scratch_var[dim.getValue() - 1] = new pdat::SideVariable<double>
             (dim, ss.str());
       ss.str("");
-      ss << "CellStokesFACOps::private_oflux_scratch" << dim.getValue();
+      ss << "StokesFACOps::private_oflux_scratch" << dim.getValue();
       s_oflux_scratch_var[dim.getValue() - 1] = new pdat::OutersideVariable<double>
             (dim, ss.str());
    }
@@ -710,7 +710,7 @@ CellStokesFACOps::CellStokesFACOps(
 
 }
 
-CellStokesFACOps::~CellStokesFACOps(
+StokesFACOps::~StokesFACOps(
    void)
 {
 }
@@ -724,7 +724,7 @@ CellStokesFACOps::~CellStokesFACOps(
  ************************************************************************
  */
 
-void CellStokesFACOps::initializeOperatorState(
+void StokesFACOps::initializeOperatorState(
    const SAMRAIVectorReal<double>& solution,
    const SAMRAIVectorReal<double>& rhs)
 {
@@ -753,10 +753,10 @@ void CellStokesFACOps::initializeOperato
       TBOX_ERROR(
          d_object_name << ": No physical bc object in\n"
          <<
-         "CellStokesFACOps::initializeOperatorState\n"
+         "StokesFACOps::initializeOperatorState\n"
          << "You must use "
          <<
-         "CellStokesFACOps::setPhysicalBcCoefObject\n"
+         "StokesFACOps::setPhysicalBcCoefObject\n"
          <<
          "to set one before calling initializeOperatorState\n");
    }
@@ -1092,7 +1092,7 @@ void CellStokesFACOps::initializeOperato
  ********************************************************************
  */
 
-void CellStokesFACOps::deallocateOperatorState()
+void StokesFACOps::deallocateOperatorState()
 {
    if (d_hierarchy) {
       int ln;
@@ -1135,7 +1135,7 @@ void CellStokesFACOps::deallocateOperato
  ********************************************************************
  */
 
-void CellStokesFACOps::postprocessOneCycle(
+void StokesFACOps::postprocessOneCycle(
    int fac_cycle_num,
    const SAMRAIVectorReal<double>& current_soln,
    const SAMRAIVectorReal<double>& residual)
@@ -1170,7 +1170,7 @@ void CellStokesFACOps::postprocessOneCyc
  ********************************************************************
  */
 
-void CellStokesFACOps::restrictSolution(
+void StokesFACOps::restrictSolution(
    const SAMRAIVectorReal<double>& s,
    SAMRAIVectorReal<double>& d,
    int dest_ln) {
@@ -1201,7 +1201,7 @@ void CellStokesFACOps::restrictSolution(
  ********************************************************************
  */
 
-void CellStokesFACOps::restrictResidual(
+void StokesFACOps::restrictResidual(
    const SAMRAIVectorReal<double>& s,
    SAMRAIVectorReal<double>& d,
    int dest_ln) {
@@ -1224,7 +1224,7 @@ void CellStokesFACOps::restrictResidual(
  ***********************************************************************
  */
 
-void CellStokesFACOps::prolongErrorAndCorrect(
+void StokesFACOps::prolongErrorAndCorrect(
    const SAMRAIVectorReal<double>& s,
    SAMRAIVectorReal<double>& d,
    int dest_ln) {
@@ -1283,7 +1283,7 @@ void CellStokesFACOps::prolongErrorAndCo
  ********************************************************************
  */
 
-void CellStokesFACOps::smoothError(
+void StokesFACOps::smoothError(
    SAMRAIVectorReal<double>& data,
    const SAMRAIVectorReal<double>& residual,
    int ln,
@@ -1302,7 +1302,7 @@ void CellStokesFACOps::smoothError(
    } else {
       TBOX_ERROR(d_object_name << ": Bad smoothing choice '"
                                << d_smoothing_choice
-                               << "' in CellStokesFACOps.");
+                               << "' in StokesFACOps.");
    }
 
    t_smooth_error->stop();
@@ -1315,7 +1315,7 @@ void CellStokesFACOps::smoothError(
  ********************************************************************
  */
 
-void CellStokesFACOps::smoothErrorByRedBlack(
+void StokesFACOps::smoothErrorByRedBlack(
    SAMRAIVectorReal<double>& data,
    const SAMRAIVectorReal<double>& residual,
    int ln,
@@ -1491,7 +1491,7 @@ void CellStokesFACOps::smoothErrorByRedB
  ********************************************************************
  */
 
-void CellStokesFACOps::ewingFixFlux(
+void StokesFACOps::ewingFixFlux(
    const hier::Patch& patch,
    const pdat::CellData<double>& soln_data,
    pdat::SideData<double>& flux_data,
@@ -1569,7 +1569,7 @@ void CellStokesFACOps::ewingFixFlux(
                &blower[0], &bupper[0],
                dx);
          } else {
-            TBOX_ERROR("CellStokesFACOps : DIM > 3 not supported" << std::endl);
+            TBOX_ERROR("StokesFACOps : DIM > 3 not supported" << std::endl);
          }
 
       }
@@ -1633,7 +1633,7 @@ void CellStokesFACOps::ewingFixFlux(
  ********************************************************************
  */
 
-int CellStokesFACOps::solveCoarsestLevel(
+int StokesFACOps::solveCoarsestLevel(
    SAMRAIVectorReal<double>& data,
    const SAMRAIVectorReal<double>& residual,
    int coarsest_ln) {
@@ -1663,7 +1663,7 @@ int CellStokesFACOps::solveCoarsestLevel
       TBOX_ERROR(d_object_name << ": Coarse level solver choice '"
                                << d_coarse_solver_choice
                                << "' unavailable in "
-                               << "scapCellStokesOps::solveCoarsestLevel.");
+                               << "scapStokesOps::solveCoarsestLevel.");
 #else
       return_value = solveCoarsestLevel_HYPRE(data, residual, coarsest_ln);
 #endif
@@ -1672,7 +1672,7 @@ int CellStokesFACOps::solveCoarsestLevel
          d_object_name << ": Bad coarse level solver choice '"
          << d_coarse_solver_choice
          <<
-         "' in scapCellStokesOps::solveCoarsestLevel.");
+         "' in scapStokesOps::solveCoarsestLevel.");
    }
 
    xeqScheduleGhostFillNoCoarse(data.getComponentDescriptorIndex(0),
@@ -1691,7 +1691,7 @@ int CellStokesFACOps::solveCoarsestLevel
  ********************************************************************
  */
 
-int CellStokesFACOps::solveCoarsestLevel_HYPRE(
+int StokesFACOps::solveCoarsestLevel_HYPRE(
    SAMRAIVectorReal<double>& data,
    const SAMRAIVectorReal<double>& residual,
    int coarsest_ln) {
@@ -1702,7 +1702,7 @@ int CellStokesFACOps::solveCoarsestLevel
    TBOX_ERROR(d_object_name << ": Coarse level solver choice '"
                             << d_coarse_solver_choice
                             << "' unavailable in "
-                            << "CellStokesFACOps::solveCoarsestLevel.");
+                            << "StokesFACOps::solveCoarsestLevel.");
 
    return 0;
 
@@ -1740,7 +1740,7 @@ int CellStokesFACOps::solveCoarsestLevel
  ********************************************************************
  */
 
-void CellStokesFACOps::computeCompositeResidualOnLevel(
+void StokesFACOps::computeCompositeResidualOnLevel(
    SAMRAIVectorReal<double>& residual,
    const SAMRAIVectorReal<double>& solution,
    const SAMRAIVectorReal<double>& rhs,
@@ -1899,7 +1899,7 @@ void CellStokesFACOps::computeCompositeR
  ********************************************************************
  */
 
-double CellStokesFACOps::computeResidualNorm(
+double StokesFACOps::computeResidualNorm(
    const SAMRAIVectorReal<double>& residual,
    int fine_ln,
    int coarse_ln)
@@ -1907,7 +1907,7 @@ double CellStokesFACOps::computeResidual
 
    if (coarse_ln != residual.getCoarsestLevelNumber() ||
        fine_ln != residual.getFinestLevelNumber()) {
-      TBOX_ERROR("CellStokesFACOps::computeResidualNorm() is not\n"
+      TBOX_ERROR("StokesFACOps::computeResidualNorm() is not\n"
          << "set up to compute residual except on the range of\n"
          << "levels defining the vector.\n");
    }
@@ -1937,7 +1937,7 @@ double CellStokesFACOps::computeResidual
  ********************************************************************
  */
 
-void CellStokesFACOps::computeVectorWeights(
+void StokesFACOps::computeVectorWeights(
    tbox::Pointer<hier::PatchHierarchy> hierarchy,
    int weight_id,
    int coarsest_ln,
@@ -2036,7 +2036,7 @@ void CellStokesFACOps::computeVectorWeig
  ********************************************************************
  */
 
-void CellStokesFACOps::checkInputPatchDataIndices() const {
+void StokesFACOps::checkInputPatchDataIndices() const {
    /*
     * Check input validity and correctness.
     */
@@ -2080,7 +2080,7 @@ void CellStokesFACOps::checkInputPatchDa
  *******************************************************************
  */
 
-void CellStokesFACOps::computeFluxOnPatch(
+void StokesFACOps::computeFluxOnPatch(
    const hier::Patch& patch,
    const hier::IntVector& ratio_to_coarser_level,
    const pdat::CellData<double>& w_data,
@@ -2193,7 +2193,7 @@ void CellStokesFACOps::computeFluxOnPatc
 
 }
 
-void CellStokesFACOps::computeResidualOnPatch(
+void StokesFACOps::computeResidualOnPatch(
    const hier::Patch& patch,
    const pdat::SideData<double>& flux_data,
    const pdat::CellData<double>& soln_data,
@@ -2353,7 +2353,7 @@ void CellStokesFACOps::computeResidualOn
    }
 }
 
-void CellStokesFACOps::redOrBlackSmoothingOnPatch(
+void StokesFACOps::redOrBlackSmoothingOnPatch(
    const hier::Patch& patch,
    const pdat::SideData<double>& flux_data,
    const pdat::CellData<double>& rhs_data,
@@ -2690,7 +2690,7 @@ void CellStokesFACOps::redOrBlackSmoothi
 }
 
 void
-CellStokesFACOps::xeqScheduleProlongation(
+StokesFACOps::xeqScheduleProlongation(
    int dst_id,
    int src_id,
    int scr_id,
@@ -2713,7 +2713,7 @@ CellStokesFACOps::xeqScheduleProlongatio
 }
 
 void
-CellStokesFACOps::xeqScheduleURestriction(
+StokesFACOps::xeqScheduleURestriction(
    int dst_id,
    int src_id,
    int dest_ln)
@@ -2733,7 +2733,7 @@ CellStokesFACOps::xeqScheduleURestrictio
 }
 
 void
-CellStokesFACOps::xeqScheduleRRestriction(
+StokesFACOps::xeqScheduleRRestriction(
    int dst_id,
    int src_id,
    int dest_ln)
@@ -2753,7 +2753,7 @@ CellStokesFACOps::xeqScheduleRRestrictio
 }
 
 void
-CellStokesFACOps::xeqScheduleFluxCoarsen(
+StokesFACOps::xeqScheduleFluxCoarsen(
    int dst_id,
    int src_id,
    int dest_ln)
@@ -2774,7 +2774,7 @@ CellStokesFACOps::xeqScheduleFluxCoarsen
 }
 
 void
-CellStokesFACOps::xeqScheduleGhostFill(
+StokesFACOps::xeqScheduleGhostFill(
    int dst_id,
    int dest_ln)
 {
@@ -2795,7 +2795,7 @@ CellStokesFACOps::xeqScheduleGhostFill(
 }
 
 void
-CellStokesFACOps::xeqScheduleGhostFillNoCoarse(
+StokesFACOps::xeqScheduleGhostFillNoCoarse(
    int dst_id,
    int dest_ln)
 {
@@ -2816,7 +2816,7 @@ CellStokesFACOps::xeqScheduleGhostFillNo
 }
 
 void
-CellStokesFACOps::finalizeCallback()
+StokesFACOps::finalizeCallback()
 {
    for (int d = 0; d < tbox::Dimension::MAXIMUM_DIMENSION_VALUE; ++d) {
       s_cell_scratch_var[d].setNull();
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACOps.I
--- a/StokesFACOps.I	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACOps.I	Fri Dec 31 12:23:51 2010 -0800
@@ -11,14 +11,14 @@ namespace solv {
 namespace solv {
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setPreconditioner(
+void StokesFACOps::setPreconditioner(
    const FACPreconditioner* preconditioner) {
    d_preconditioner = preconditioner;
 }
 
 #ifdef HAVE_HYPRE
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setUseSMG(
+void StokesFACOps::setUseSMG(
    bool use_smg)
 {
    if (d_hierarchy) {
@@ -39,7 +39,7 @@ void CellStokesFACOps::setUseSMG(
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setPhysicalBcCoefObject(
+void StokesFACOps::setPhysicalBcCoefObject(
    const RobinBcCoefStrategy* physical_bc_coef)
 {
    d_physical_bc_coef = physical_bc_coef;
@@ -56,7 +56,7 @@ void CellStokesFACOps::setPhysicalBcCoef
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setStokesSpecifications(
+void StokesFACOps::setStokesSpecifications(
    const StokesSpecifications& spec)
 {
    d_stokes_spec = spec;
@@ -68,7 +68,7 @@ void CellStokesFACOps::setStokesSpecific
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::enableLogging(
+void StokesFACOps::enableLogging(
    bool enable_logging)
 {
    d_enable_logging = enable_logging;
@@ -81,7 +81,7 @@ void CellStokesFACOps::enableLogging(
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setFluxId(
+void StokesFACOps::setFluxId(
    int flux_id) {
    d_flux_id = flux_id;
 #ifdef DEBUG_CHECK_ASSERTIONS
@@ -96,14 +96,14 @@ void CellStokesFACOps::setFluxId(
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setSmoothingChoice(
+void StokesFACOps::setSmoothingChoice(
    const std::string& smoothing_choice)
 {
 #ifdef DEBUG_CHECK_ASSERTIONS
    if (smoothing_choice != "redblack") {
       TBOX_ERROR(d_object_name << ": Bad smoothing choice '"
                                << smoothing_choice
-                               << "' in CellStokesFACOps::setSmoothingChoice.");
+                               << "' in StokesFACOps::setSmoothingChoice.");
    }
 #endif
    d_smoothing_choice = smoothing_choice;
@@ -116,7 +116,7 @@ void CellStokesFACOps::setSmoothingChoic
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setCoarsestLevelSolverChoice(
+void StokesFACOps::setCoarsestLevelSolverChoice(
    const std::string& choice) {
 #ifdef DEBUG_CHECK_ASSERTIONS
 #ifndef HAVE_HYPRE
@@ -133,7 +133,7 @@ void CellStokesFACOps::setCoarsestLevelS
          d_object_name << ": Bad coarse level solver choice '"
          << choice
          <<
-         "' in scapCellStokesOpsX::setCoarseLevelSolver.");
+         "' in scapStokesOpsX::setCoarseLevelSolver.");
    }
 }
 
@@ -144,7 +144,7 @@ void CellStokesFACOps::setCoarsestLevelS
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setCoarsestLevelSolverTolerance(
+void StokesFACOps::setCoarsestLevelSolverTolerance(
    double tol) {
    d_coarse_solver_tolerance = tol;
 }
@@ -156,7 +156,7 @@ void CellStokesFACOps::setCoarsestLevelS
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setCoarsestLevelSolverMaxIterations(
+void StokesFACOps::setCoarsestLevelSolverMaxIterations(
    int max_iterations) {
 #ifdef DEBUG_CHECK_ASSERTIONS
    if (max_iterations < 0) {
@@ -173,7 +173,7 @@ void CellStokesFACOps::setCoarsestLevelS
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setCoarseFineDiscretization(
+void StokesFACOps::setCoarseFineDiscretization(
    const std::string& coarsefine_method) {
 #ifdef DEBUG_CHECK_ASSERTIONS
    if (d_hierarchy) {
@@ -195,7 +195,7 @@ void CellStokesFACOps::setCoarseFineDisc
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACOps::setProlongationMethod(
+void StokesFACOps::setProlongationMethod(
    const std::string& prolongation_method) {
 #ifdef DEBUG_CHECK_ASSERTIONS
    if (d_hierarchy) {
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACOps.h
--- a/StokesFACOps.h	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACOps.h	Fri Dec 31 12:23:51 2010 -0800
@@ -113,7 +113,7 @@ namespace solv {
  * hypre_solver = { ... }            // tbox::Database for initializing Hypre solver
  * @endverbatim
  */
-class CellStokesFACOps:
+class StokesFACOps:
    public FACOperatorStrategy
 {
 
@@ -126,7 +126,7 @@ public:
     * @param object_name Ojbect name
     * @param database Input database
     */
-   CellStokesFACOps(
+   StokesFACOps(
       const tbox::Dimension& dim,
       const std::string& object_name = std::string(),
       tbox::Pointer<tbox::Database> database =
@@ -137,7 +137,7 @@ public:
     *
     * Deallocate internal data.
     */
-   ~CellStokesFACOps(
+   ~StokesFACOps(
       void);
 
    /*!
@@ -870,7 +870,7 @@ private:
    /*!
     * @brief HYPRE coarse-level solver object.
     */
-   CellStokesHypreSolver d_hypre_solver;
+   StokesHypreSolver d_hypre_solver;
 #endif
 
    /*!
@@ -1038,7 +1038,7 @@ private:
 }
 
 #ifdef SAMRAI_INLINE
-#include "CellStokesFACOps.I"
+#include "StokesFACOps.I"
 #endif
 
-#endif // included_solv_CellStokesFACOps
+#endif // included_solv_StokesFACOps
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACSolver.I
--- a/StokesFACSolver.I	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACSolver.I	Fri Dec 31 12:23:51 2010 -0800
@@ -11,25 +11,25 @@ namespace solv {
 namespace solv {
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setDPatchDataId(
+void StokesFACSolver::setDPatchDataId(
    int id) {
    d_stokes_spec.setDPatchDataId(id);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setDConstant(
+void StokesFACSolver::setDConstant(
    double scalar) {
    d_stokes_spec.setDConstant(scalar);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCPatchDataId(
+void StokesFACSolver::setCPatchDataId(
    int id) {
    d_stokes_spec.setCPatchDataId(id);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCConstant(
+void StokesFACSolver::setCConstant(
    double scalar) {
 // Disable Intel warning on real comparison
 #ifdef __INTEL_COMPILER
@@ -43,35 +43,35 @@ void CellStokesFACSolver::setCConstant(
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setProlongationMethod(
+void StokesFACSolver::setProlongationMethod(
    const std::string& prolongation_method)
 {
    d_fac_ops.setProlongationMethod(prolongation_method);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCoarsestLevelSolverChoice(
+void StokesFACSolver::setCoarsestLevelSolverChoice(
    const std::string& choice)
 {
    d_fac_ops.setCoarsestLevelSolverChoice(choice);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCoarsestLevelSolverTolerance(
+void StokesFACSolver::setCoarsestLevelSolverTolerance(
    double tol)
 {
    d_fac_ops.setCoarsestLevelSolverTolerance(tol);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCoarsestLevelSolverMaxIterations(
+void StokesFACSolver::setCoarsestLevelSolverMaxIterations(
    int max_iterations)
 {
    d_fac_ops.setCoarsestLevelSolverMaxIterations(max_iterations);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setCoarseFineDiscretization(
+void StokesFACSolver::setCoarseFineDiscretization(
    const std::string& coarsefine_method)
 {
    d_fac_ops.setCoarseFineDiscretization(coarsefine_method);
@@ -79,7 +79,7 @@ void CellStokesFACSolver::setCoarseFineD
 
 #ifdef HAVE_HYPRE
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setUseSMG(
+void StokesFACSolver::setUseSMG(
    bool use_smg)
 {
    if (d_solver_is_initialized) {
@@ -94,43 +94,43 @@ void CellStokesFACSolver::setUseSMG(
 #endif
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setPresmoothingSweeps(
+void StokesFACSolver::setPresmoothingSweeps(
    int num_pre_sweeps) {
    d_fac_precond.setPresmoothingSweeps(num_pre_sweeps);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setPostsmoothingSweeps(
+void StokesFACSolver::setPostsmoothingSweeps(
    int num_post_sweeps) {
    d_fac_precond.setPostsmoothingSweeps(num_post_sweeps);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setMaxCycles(
+void StokesFACSolver::setMaxCycles(
    int max_cycles) {
    d_fac_precond.setMaxCycles(max_cycles);
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::setResidualTolerance(
+void StokesFACSolver::setResidualTolerance(
    double residual_tol) {
    d_fac_precond.setResidualTolerance(residual_tol);
 }
 
 SAMRAI_INLINE_KEYWORD
-int CellStokesFACSolver::getNumberOfIterations() const
+int StokesFACSolver::getNumberOfIterations() const
 {
    return d_fac_precond.getNumberOfIterations();
 }
 
 SAMRAI_INLINE_KEYWORD
-double CellStokesFACSolver::getResidualNorm() const
+double StokesFACSolver::getResidualNorm() const
 {
    return d_fac_precond.getResidualNorm();
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesFACSolver::getConvergenceFactors(
+void StokesFACSolver::getConvergenceFactors(
    double& avg_factor,
    double& final_factor)
 const
diff -r fe2a9230921b -r 3e8175cdd1ef StokesHypreSolver.C
--- a/StokesHypreSolver.C	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesHypreSolver.C	Fri Dec 31 12:23:51 2010 -0800
@@ -262,13 +262,13 @@ namespace solv {
 namespace solv {
 
 tbox::Pointer<pdat::OutersideVariable<double> >
-CellStokesHypreSolver::s_Ak0_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
+StokesHypreSolver::s_Ak0_var[tbox::Dimension::MAXIMUM_DIMENSION_VALUE];
 
-tbox::StartupShutdownManager::Handler CellStokesHypreSolver::s_finalize_handler(
+tbox::StartupShutdownManager::Handler StokesHypreSolver::s_finalize_handler(
    0,
    0,
    0,
-   CellStokesHypreSolver::finalizeCallback,
+   StokesHypreSolver::finalizeCallback,
    tbox::StartupShutdownManager::priorityVariables);
 
 /*
@@ -277,7 +277,7 @@ tbox::StartupShutdownManager::Handler Ce
  *************************************************************************
  */
 
-CellStokesHypreSolver::CellStokesHypreSolver(
+StokesHypreSolver::StokesHypreSolver(
    const tbox::Dimension& dim,
    const std::string& object_name,
    tbox::Pointer<tbox::Database> database):
@@ -312,13 +312,13 @@ CellStokesHypreSolver::CellStokesHypreSo
    d_print_solver_info(false)
 {
    if (d_dim == tbox::Dimension(1) || d_dim > tbox::Dimension(3)) {
-      TBOX_ERROR(" CellStokesHypreSolver : DIM == 1 or > 3 not implemented");
+      TBOX_ERROR(" StokesHypreSolver : DIM == 1 or > 3 not implemented");
    }
 
    t_solve_system = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesHypreSolver::solveSystem()");
+      getTimer("solv::StokesHypreSolver::solveSystem()");
    t_set_matrix_coefficients = tbox::TimerManager::getManager()->
-      getTimer("solv::CellStokesHypreSolver::setMatrixCoefficients()");
+      getTimer("solv::StokesHypreSolver::setMatrixCoefficients()");
 
    hier::VariableDatabase* vdb = hier::VariableDatabase::getDatabase();
    if (s_Ak0_var[d_dim.getValue() - 1].isNull()) {
@@ -340,7 +340,7 @@ CellStokesHypreSolver::CellStokesHypreSo
  ********************************************************************
  */
 
-void CellStokesHypreSolver::getFromInput(
+void StokesHypreSolver::getFromInput(
    tbox::Pointer<tbox::Database> database)
 {
    if (database) {
@@ -352,7 +352,7 @@ void CellStokesHypreSolver::getFromInput
             "relative_residual_tol",
             d_relative_residual_tol);
       if (database->isDouble("residual_tol")) {
-         TBOX_ERROR("CellStokesHypreSolver input error.\n"
+         TBOX_ERROR("StokesHypreSolver input error.\n"
             << "The parameter 'residual_tol' has been replaced\n"
             << "by 'relative_residual_tol' to be more descriptive.\n"
             << "Please change the parameter name in the input database.");
@@ -390,7 +390,7 @@ void CellStokesHypreSolver::getFromInput
  ********************************************************************
  */
 
-void CellStokesHypreSolver::initializeSolverState(
+void StokesHypreSolver::initializeSolverState(
    tbox::Pointer<hier::PatchHierarchy> hierarchy,
    int ln)
 {
@@ -421,7 +421,7 @@ void CellStokesHypreSolver::initializeSo
  ********************************************************************
  */
 
-void CellStokesHypreSolver::deallocateSolverState()
+void StokesHypreSolver::deallocateSolverState()
 {
    if (d_hierarchy.isNull()) return;
 
@@ -441,7 +441,7 @@ void CellStokesHypreSolver::deallocateSo
  *                                                                       *
  *************************************************************************
  */
-void CellStokesHypreSolver::allocateHypreData()
+void StokesHypreSolver::allocateHypreData()
 {
    tbox::SAMRAI_MPI::Comm communicator = d_hierarchy->getDomainMappedBoxLevel().getMPI().getCommunicator();
 
@@ -581,7 +581,7 @@ void CellStokesHypreSolver::allocateHypr
          no_ghosts = no_ghosts3;
       } else {
          TBOX_ERROR(
-            "CellStokesHypreSolver does not yet support dimension " << d_dim);
+            "StokesHypreSolver does not yet support dimension " << d_dim);
       }
 
       HYPRE_StructMatrixCreate(communicator,
@@ -614,7 +614,7 @@ void CellStokesHypreSolver::allocateHypr
  *************************************************************************
  */
 
-CellStokesHypreSolver::~CellStokesHypreSolver()
+StokesHypreSolver::~StokesHypreSolver()
 {
    deallocateHypreData();
 
@@ -638,7 +638,7 @@ CellStokesHypreSolver::~CellStokesHypreS
  *************************************************************************
  */
 
-void CellStokesHypreSolver::deallocateHypreData()
+void StokesHypreSolver::deallocateHypreData()
 {
    if (d_stencil) {
       HYPRE_StructStencilDestroy(d_stencil);
@@ -671,7 +671,7 @@ void CellStokesHypreSolver::deallocateHy
  *************************************************************************
  */
 
-void CellStokesHypreSolver::copyToHypre(
+void StokesHypreSolver::copyToHypre(
    HYPRE_StructVector vector,
    pdat::CellData<double>& src,
    int depth,
@@ -693,7 +693,7 @@ void CellStokesHypreSolver::copyToHypre(
  *************************************************************************
  */
 
-void CellStokesHypreSolver::copyFromHypre(
+void StokesHypreSolver::copyFromHypre(
    pdat::CellData<double>& dst,
    int depth,
    HYPRE_StructVector vector,
@@ -720,7 +720,7 @@ void CellStokesHypreSolver::copyFromHypr
  *************************************************************************
  */
 
-void CellStokesHypreSolver::setMatrixCoefficients(
+void StokesHypreSolver::setMatrixCoefficients(
    const StokesSpecifications& spec)
 {
    if (d_physical_bc_coef_strategy == NULL) {
@@ -888,7 +888,7 @@ void CellStokesHypreSolver::setMatrixCoe
                TBOX_ERROR(
                   d_object_name << ": Illegal boundary type in "
                   <<
-                  "CellStokesHypreSolver::setMatrixCoefficients\n");
+                  "StokesHypreSolver::setMatrixCoefficients\n");
             }
             const hier::BoundaryBoxUtils bbu(boundary_box);
             const int location_index = boundary_box.getLocationIndex();
@@ -950,7 +950,7 @@ void CellStokesHypreSolver::setMatrixCoe
                TBOX_ERROR(
                   d_object_name << ": Illegal boundary type in "
                   <<
-                  "CellStokesHypreSolver::setMatrixCoefficients\n");
+                  "StokesHypreSolver::setMatrixCoefficients\n");
             }
             const int location_index = boundary_box.getLocationIndex();
             const hier::BoundaryBoxUtils bbu(boundary_box);
@@ -1065,7 +1065,7 @@ void CellStokesHypreSolver::setMatrixCoe
  **********************************************************************
  */
 
-void CellStokesHypreSolver::add_gAk0_toRhs(
+void StokesHypreSolver::add_gAk0_toRhs(
    const hier::Patch& patch,
    const tbox::Array<hier::BoundaryBox>& bdry_boxes,
    const RobinBcCoefStrategy* robin_bc_coef,
@@ -1094,7 +1094,7 @@ void CellStokesHypreSolver::add_gAk0_toR
 #ifdef DEBUG_CHECK_ASSERTIONS
       if (boundary_box.getBoundaryType() != 1) {
          TBOX_ERROR(d_object_name << ": Illegal boundary type in "
-                                  << "CellStokesHypreSolver::add_gAk0_toRhs\n");
+                                  << "StokesHypreSolver::add_gAk0_toRhs\n");
       }
 #endif
       const int location_index = boundary_box.getLocationIndex();
@@ -1176,7 +1176,7 @@ void CellStokesHypreSolver::add_gAk0_toR
  * Create the hypre solver and set it according to the current state.    *
  *************************************************************************
  */
-void CellStokesHypreSolver::setupHypreSolver()
+void StokesHypreSolver::setupHypreSolver()
 {
    TBOX_ASSERT(d_mg_data == NULL);
 
@@ -1212,7 +1212,7 @@ void CellStokesHypreSolver::setupHypreSo
    }
 }
 
-void CellStokesHypreSolver::destroyHypreSolver()
+void StokesHypreSolver::destroyHypreSolver()
 {
    if (d_mg_data != NULL) {
       if (d_use_smg) {
@@ -1233,7 +1233,7 @@ void CellStokesHypreSolver::destroyHypre
  *************************************************************************
  */
 
-int CellStokesHypreSolver::solveSystem(
+int StokesHypreSolver::solveSystem(
    const int u,
    const int f,
    bool homogeneous_bc)
@@ -1247,7 +1247,7 @@ int CellStokesHypreSolver::solveSystem(
          "to specify the boundary conidition.  Do it before\n"
          << "calling solveSystem.");
    }
-   // Tracer t("CellStokesHypreSolver::solveSystem");
+   // Tracer t("StokesHypreSolver::solveSystem");
 
    t_solve_system->start();
 
@@ -1401,7 +1401,7 @@ int CellStokesHypreSolver::solveSystem(
    return d_relative_residual_norm <= d_relative_residual_tol;
 }
 
-void CellStokesHypreSolver::computeDiagonalEntries(
+void StokesHypreSolver::computeDiagonalEntries(
    pdat::CellData<double>& diagonal,
    const pdat::CellData<double>& C_data,
    const pdat::SideData<double>& off_diagonal,
@@ -1437,7 +1437,7 @@ void CellStokesHypreSolver::computeDiago
    }
 }
 
-void CellStokesHypreSolver::computeDiagonalEntries(
+void StokesHypreSolver::computeDiagonalEntries(
    pdat::CellData<double>& diagonal,
    const double C,
    const pdat::SideData<double>& off_diagonal,
@@ -1467,12 +1467,12 @@ void CellStokesHypreSolver::computeDiago
          &patch_lo[2], &patch_up[2],
          &c, &d);
    } else {
-      TBOX_ERROR("CellStokesHypreSolver error...\n"
+      TBOX_ERROR("StokesHypreSolver error...\n"
          << "DIM > 3 not supported." << std::endl);
    }
 }
 
-void CellStokesHypreSolver::computeDiagonalEntries(
+void StokesHypreSolver::computeDiagonalEntries(
    pdat::CellData<double>& diagonal,
    const pdat::SideData<double>& off_diagonal,
    const hier::Box& patch_box)
@@ -1499,12 +1499,12 @@ void CellStokesHypreSolver::computeDiago
          &patch_lo[2], &patch_up[2],
          &c, &d);
    } else {
-      TBOX_ERROR("CellStokesHypreSolver error...\n"
+      TBOX_ERROR("StokesHypreSolver error...\n"
          << "DIM > 3 not supported." << std::endl);
    }
 }
 
-void CellStokesHypreSolver::adjustBoundaryEntries(
+void StokesHypreSolver::adjustBoundaryEntries(
    pdat::CellData<double>& diagonal,
    const pdat::SideData<double>& off_diagonal,
    const hier::Box& patch_box,
@@ -1570,13 +1570,13 @@ void CellStokesHypreSolver::adjustBounda
          &lower[0], &upper[0],
          &location_index, h);
    } else {
-      TBOX_ERROR("CellStokesHypreSolver error...\n"
+      TBOX_ERROR("StokesHypreSolver error...\n"
          << "DIM > 3 not supported." << std::endl);
    }
 }
 
 void
-CellStokesHypreSolver::finalizeCallback()
+StokesHypreSolver::finalizeCallback()
 {
    for (int d = 0; d < tbox::Dimension::MAXIMUM_DIMENSION_VALUE; ++d) {
       s_Ak0_var[d].setNull();
diff -r fe2a9230921b -r 3e8175cdd1ef StokesHypreSolver.I
--- a/StokesHypreSolver.I	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesHypreSolver.I	Fri Dec 31 12:23:51 2010 -0800
@@ -11,19 +11,19 @@ namespace solv {
 namespace solv {
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setSolnIdDepth(
+void StokesHypreSolver::setSolnIdDepth(
    const int depth) {
    d_soln_depth = depth;
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setRhsIdDepth(
+void StokesHypreSolver::setRhsIdDepth(
    const int depth) {
    d_rhs_depth = depth;
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setUseSMG(
+void StokesHypreSolver::setUseSMG(
    bool use_smg) {
    d_use_smg = use_smg;
 }
@@ -36,7 +36,7 @@ void CellStokesHypreSolver::setUseSMG(
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setBoundaries(
+void StokesHypreSolver::setBoundaries(
    const std::string& boundary_type,
    const int fluxes,
    const int flags,
@@ -57,7 +57,7 @@ void CellStokesHypreSolver::setBoundarie
  */
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setPhysicalBcCoefObject(
+void StokesHypreSolver::setPhysicalBcCoefObject(
    const RobinBcCoefStrategy* physical_bc_coef_strategy,
    const tbox::Pointer<hier::Variable> variable)
 {
@@ -66,19 +66,19 @@ void CellStokesHypreSolver::setPhysicalB
 }
 
 SAMRAI_INLINE_KEYWORD
-int CellStokesHypreSolver::getNumberOfIterations() const
+int StokesHypreSolver::getNumberOfIterations() const
 {
    return d_number_iterations;
 }
 
 SAMRAI_INLINE_KEYWORD
-double CellStokesHypreSolver::getRelativeResidualNorm() const
+double StokesHypreSolver::getRelativeResidualNorm() const
 {
    return d_relative_residual_norm;
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setNumPreRelaxSteps(
+void StokesHypreSolver::setNumPreRelaxSteps(
    const int steps)
 {
 #ifdef DEBUG_CHECK_ASSERTIONS
@@ -88,7 +88,7 @@ void CellStokesHypreSolver::setNumPreRel
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setNumPostRelaxSteps(
+void StokesHypreSolver::setNumPostRelaxSteps(
    const int steps)
 {
 #ifdef DEBUG_CHECK_ASSERTIONS
@@ -98,14 +98,14 @@ void CellStokesHypreSolver::setNumPostRe
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setPrintSolverInfo(
+void StokesHypreSolver::setPrintSolverInfo(
    const bool print)
 {
    d_print_solver_info = print;
 }
 
 SAMRAI_INLINE_KEYWORD
-void CellStokesHypreSolver::setStoppingCriteria(
+void StokesHypreSolver::setStoppingCriteria(
    const int max_iterations,
    const double residual_tol)
 {
diff -r fe2a9230921b -r 3e8175cdd1ef FACStokes.h
--- a/FACStokes.h	Fri Dec 31 12:10:26 2010 -0800
+++ b/FACStokes.h	Fri Dec 31 12:23:51 2010 -0800
@@ -102,7 +102,7 @@ namespace SAMRAI {
      * @brief Solve using HYPRE Stokes solver
      *
      * Set up the linear algebra problem and use a
      * solv::CellStokesFACSolver object to solve it.
      * -# Set initial guess
      * -# Set boundary conditions
      * -# Specify Stokes equation parameters
@@ -148,7 +148,7 @@ namespace SAMRAI {
     /*!
      * @brief FAC stokes solver.
      */
-    solv::CellStokesFACSolver d_stokes_fac_solver;
+    solv::StokesFACSolver d_stokes_fac_solver;
 
     /*!
      * @brief Boundary condition coefficient implementation.
@@ -102,7 +102,7 @@ namespace SAMRAI {
      *
      * Set up the linear algebra problem and use a
-     * solv::CellStokesFACSolver object to solve it.
+     * solv::StokesFACSolver object to solve it.
      * -# Set initial guess
      * -# Set boundary conditions
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACSolver.C
--- a/StokesFACSolver.C	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACSolver.C	Fri Dec 31 12:23:51 2010 -0800
@@ -33,10 +33,10 @@ namespace solv {
  *************************************************************************
  */
 
-bool CellStokesFACSolver::s_initialized = 0;
-int CellStokesFACSolver::s_weight_id[SAMRAI::tbox::Dimension::
+bool StokesFACSolver::s_initialized = 0;
+int StokesFACSolver::s_weight_id[SAMRAI::tbox::Dimension::
                                       MAXIMUM_DIMENSION_VALUE];
-int CellStokesFACSolver::s_instance_counter[SAMRAI::tbox::Dimension::
+int StokesFACSolver::s_instance_counter[SAMRAI::tbox::Dimension::
                                              MAXIMUM_DIMENSION_VALUE];
 
 /*
@@ -54,7 +54,7 @@ int CellStokesFACSolver::s_instance_coun
  *************************************************************************
  */
 
-CellStokesFACSolver::CellStokesFACSolver(
+StokesFACSolver::StokesFACSolver(
    const tbox::Dimension& dim,
    const std::string& object_name,
    tbox::Pointer<tbox::Database> database):
@@ -106,7 +106,7 @@ CellStokesFACSolver::CellStokesFACSolver
     */
    hier::VariableDatabase* var_db = hier::VariableDatabase::getDatabase();
 
-   static std::string weight_variable_name("CellStokesFACSolver_weight");
+   static std::string weight_variable_name("StokesFACSolver_weight");
 
    tbox::Pointer<pdat::CellVariable<double> > weight = var_db->getVariable(
          weight_variable_name);
@@ -144,13 +144,13 @@ CellStokesFACSolver::CellStokesFACSolver
 /*
  *************************************************************************
  *                                                                       *
  * Destructor for CellStokesFACSolver.                            *
  * Deallocate internal data.                                             *
  *                                                                       *
  *************************************************************************
  */
 
-CellStokesFACSolver::~CellStokesFACSolver()
+StokesFACSolver::~StokesFACSolver()
 {
    s_instance_counter[d_dim.getValue() - 1]--;
 
@@ -177,7 +177,7 @@ CellStokesFACSolver::~CellStokesFACSolve
  ********************************************************************
  */
 
-void CellStokesFACSolver::getFromInput(
+void StokesFACSolver::getFromInput(
    tbox::Pointer<tbox::Database> database)
 {
    if (database) {
@@ -243,7 +243,7 @@ void CellStokesFACSolver::getFromInput(
  *************************************************************************
  */
 
-void CellStokesFACSolver::initializeSolverState(
+void StokesFACSolver::initializeSolverState(
    const int solution,
    const int rhs,
    tbox::Pointer<hier::PatchHierarchy> hierarchy,
@@ -321,7 +321,7 @@ void CellStokesFACSolver::initializeSolv
    d_solver_is_initialized = true;
 }
 
-void CellStokesFACSolver::deallocateSolverState()
+void StokesFACSolver::deallocateSolverState()
 {
    if (d_hierarchy) {
 
@@ -352,7 +352,7 @@ void CellStokesFACSolver::deallocateSolv
  *************************************************************************
  */
 
-void CellStokesFACSolver::enableLogging(
+void StokesFACSolver::enableLogging(
    bool logging)
 {
    d_enable_logging = logging;
@@ -360,7 +360,7 @@ void CellStokesFACSolver::enableLogging(
    d_fac_ops.enableLogging(d_enable_logging);
 }
 
-void CellStokesFACSolver::setBoundaries(
+void StokesFACSolver::setBoundaries(
    const std::string& boundary_type,
    const int fluxes,
    const int flags,
@@ -382,7 +382,7 @@ void CellStokesFACSolver::setBoundaries(
    d_fac_ops.setPhysicalBcCoefObject(d_bc_object);
 }
 
-void CellStokesFACSolver::setBcObject(
+void StokesFACSolver::setBcObject(
    const RobinBcCoefStrategy* bc_object)
 {
 #ifdef DEBUG_CHECK_ASSERTIONS
@@ -408,7 +408,7 @@ void CellStokesFACSolver::setBcObject(
  *************************************************************************
  */
 
-bool CellStokesFACSolver::solveSystem(
+bool StokesFACSolver::solveSystem(
    const int u,
    const int f)
 {
@@ -468,7 +468,7 @@ bool CellStokesFACSolver::solveSystem(
  *************************************************************************
  */
 
-bool CellStokesFACSolver::solveSystem(
+bool StokesFACSolver::solveSystem(
    const int u,
    const int f,
    tbox::Pointer<hier::PatchHierarchy> hierarchy,
@@ -479,7 +479,7 @@ bool CellStokesFACSolver::solveSystem(
    TBOX_DIM_ASSERT_CHECK_DIM_ARGS1(d_dim, *hierarchy);
 
    if (d_enable_logging) {
-      tbox::plog << "CellStokesFACSolver::solveSystem (" << d_object_name
+      tbox::plog << "StokesFACSolver::solveSystem (" << d_object_name
                  << ")\n";
       d_stokes_spec.printClassData(tbox::plog);
    }
@@ -509,7 +509,7 @@ bool CellStokesFACSolver::solveSystem(
    return solver_rval;
 }
 
-void CellStokesFACSolver::createVectorWrappers(
+void StokesFACSolver::createVectorWrappers(
    int u,
    int f) {
 
@@ -565,12 +565,12 @@ void CellStokesFACSolver::createVectorWr
  * we do not control their data allocation.  The user does that.       *
  ***********************************************************************
  */
-void CellStokesFACSolver::destroyVectorWrappers() {
+void StokesFACSolver::destroyVectorWrappers() {
    d_uv.setNull();
    d_fv.setNull();
 }
 
-void CellStokesFACSolver::initializeStatics() {
+void StokesFACSolver::initializeStatics() {
 
    for (int d = 0; d < SAMRAI::tbox::Dimension::MAXIMUM_DIMENSION_VALUE; ++d) {
       s_weight_id[d] = -1;
@@ -144,13 +144,13 @@ CellStokesFACSolver::CellStokesFACSolver
  *************************************************************************
  *                                                                       *
- * Destructor for CellStokesFACSolver.                            *
+ * Destructor for StokesFACSolver.                            *
  * Deallocate internal data.                                             *
  *                                                                       *
diff -r fe2a9230921b -r 3e8175cdd1ef StokesFACSolver.h
--- a/StokesFACSolver.h	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesFACSolver.h	Fri Dec 31 12:23:51 2010 -0800
@@ -56,7 +56,7 @@ namespace solv {
  * Computation, Vol. 56, No. 194, April 1991, pp. 437-461).
  *
  * Typical use of this class is:
  * -# Construct a CellStokesFACSolver object, providing it
  *    the hierarchy and range of levels participating in the solve.
  * -# Set the parameters C and D using the functions named @c setC...
  *    and @c setD...  By default, D=1 and C=0 everywhere.
@@ -110,7 +110,7 @@ namespace solv {
  * @endverbatim
  *
  */
-class CellStokesFACSolver
+class StokesFACSolver
 {
 
 public:
@@ -125,7 +125,7 @@ public:
     * @param object_name Name of object used in outputs
     * @param database tbox::Database for initialization (may be NULL)
     */
-   CellStokesFACSolver(
+   StokesFACSolver(
       const tbox::Dimension& dim,
       const std::string& object_name,
       tbox::Pointer<tbox::Database> database =
@@ -134,7 +134,7 @@ public:
    /*!
     * @brief Destructor.
     */
-   ~CellStokesFACSolver(
+   ~StokesFACSolver(
       void);
 
    /*!
@@ -606,7 +606,7 @@ private:
     * @brief FAC operator implementation corresponding to cell-centered
     * Stokes discretization.
     */
-   CellStokesFACOps d_fac_ops;
+   StokesFACOps d_fac_ops;
 
    /*!
     * @brief FAC preconditioner algorithm.
@@ -657,4 +657,4 @@ private:
 #include "StokesFACSolver.I"
 #endif
 
-#endif  // included_solv_CellStokesFACSolver
+#endif  // included_solv_StokesFACSolver
@@ -56,7 +56,7 @@ namespace solv {
  *
  * Typical use of this class is:
- * -# Construct a CellStokesFACSolver object, providing it
+ * -# Construct a StokesFACSolver object, providing it
  *    the hierarchy and range of levels participating in the solve.
  * -# Set the parameters C and D using the functions named @c setC...
diff -r fe2a9230921b -r 3e8175cdd1ef StokesHypreSolver.h
--- a/StokesHypreSolver.h	Fri Dec 31 12:10:26 2010 -0800
+++ b/StokesHypreSolver.h	Fri Dec 31 12:23:51 2010 -0800
@@ -52,7 +52,7 @@ namespace solv {
  * @brief Use the HYPRE preconditioner library to solve (the cell-centered)
  * Stokes's equation on a single level in a hierarchy.
  *
  * Class CellStokesHypreSolver uses the HYPRE preconditioner library
  * to solve linear equations of the form
  * @f$ \nabla ( D \nabla u ) + C u = f @f$, where
  * C is a cell-centered array, D is a face-centered array,
@@ -66,9 +66,9 @@ namespace solv {
  * Periodic boundary conditions are not supported yet.
  *
  * The user must perform the following steps to use
  * CellStokesHypreSolver:
  * - Create a CellStokesHypreSolver object.
  * - Initialize CellStokesHypreSolver object with a patch hierarchy,
  *   using the function initializeSolverState().
  * - Use the functions setPhysicalBcCoefObject()
  *   to provide implementations of RobinBcCoefStrategy.
@@ -95,7 +95,7 @@ namespace solv {
  * @endverbatim
  */
 
-class CellStokesHypreSolver
+class StokesHypreSolver
 {
 public:
    /*!
@@ -104,7 +104,7 @@ public:
     * @param object_name Name of object.
     * @param database tbox::Database for input.
     */
-   CellStokesHypreSolver(
+   StokesHypreSolver(
       const tbox::Dimension& dim,
       const std::string& object_name,
       tbox::Pointer<tbox::Database> database =
@@ -113,7 +113,7 @@ public:
    /*!
     * The Stokes destructor releases all internally managed data.
     */
-   ~CellStokesHypreSolver();
+   ~StokesHypreSolver();
 
    /*!
     * @brief Initialize to a given hierarchy.
@@ -52,7 +52,7 @@ namespace solv {
  * Stokes's equation on a single level in a hierarchy.
  *
- * Class CellStokesHypreSolver uses the HYPRE preconditioner library
+ * Class StokesHypreSolver uses the HYPRE preconditioner library
  * to solve linear equations of the form
  * @f$ \nabla ( D \nabla u ) + C u = f @f$, where
@@ -66,9 +66,9 @@ namespace solv {
  *
  * The user must perform the following steps to use
- * CellStokesHypreSolver:
- * - Create a CellStokesHypreSolver object.
- * - Initialize CellStokesHypreSolver object with a patch hierarchy,
+ * StokesHypreSolver:
+ * - Create a StokesHypreSolver object.
+ * - Initialize StokesHypreSolver object with a patch hierarchy,
  *   using the function initializeSolverState().
  * - Use the functions setPhysicalBcCoefObject()



More information about the CIG-COMMITS mailing list